@@ -1,28 +1,33 @@
-from Acquisition import aq_parent, aq_inner
-
-from zope.interface import implementer, Interface
-from zope.interface.declarations import ObjectSpecificationDescriptor
-from zope.interface.declarations import getObjectSpecification
-from zope.cachedescriptors.property import Lazy as lazy_property
-from zope.component import adapts, getAdapters
-from zope.event import notify
-from zope.schema.interfaces import IField
-from zope.security.interfaces import ForbiddenAttribute
-from zope import schema
-from zope.i18nmessageid import Message
-
-from z3c.form import form, field, button
-from z3c.form.interfaces import IDataManager
-from z3c.form.datamanager import AttributeField
-from plone.z3cform.layout import wrap_form
+# -*- coding: utf-8 -*-
+from Acquisition import aq_inner
 from plone.autoform.form import AutoExtensibleForm
+from plone.schemaeditor import _
+from plone.schemaeditor import interfaces
+from plone.schemaeditor.interfaces import IFieldEditForm
+from plone.schemaeditor.utils import SchemaModifiedEvent
+from plone.z3cform.layout import wrap_form
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from Products.statusmessages.interfaces import IStatusMessage
+from z3c.form import button
+from z3c.form import field
+from z3c.form import form
+from z3c.form.datamanager import AttributeField
+from z3c.form.interfaces import IDataManager
+from zope import schema
+from zope.cachedescriptors.property import Lazy as lazy_property
+from zope.component import adapter
+from zope.component import getAdapters
+from zope.event import notify
+from zope.i18nmessageid import Message
+from zope.interface import implementer
+from zope.interface import Interface
+from zope.interface.declarations import getObjectSpecification
+from zope.interface.declarations import ObjectSpecificationDescriptor
+from zope.schema.interfaces import IField
+from zope.security.interfaces import ForbiddenAttribute
 
-from plone.schemaeditor.interfaces import IFieldEditForm
-from plone.schemaeditor import interfaces
-from plone.schemaeditor.utils import SchemaModifiedEvent
-from plone.schemaeditor import _
+
+import six
 
 
 _marker = object()
@@ -32,14 +37,14 @@ class IFieldTitle(Interface):
     title = schema.TextLine(
         title=schema.interfaces.ITextLine['title'].title,
         description=schema.interfaces.ITextLine['title'].description,
-        default=u"",
+        default=u'',
         required=True,
     )
 
 
 @implementer(IFieldTitle)
+@adapter(IField)
 class FieldTitleAdapter(object):
-    adapts(IField)
 
     def __init__(self, field):
         self.field = field
@@ -57,6 +62,7 @@ class IFieldProxy(Interface):
 
 
 class FieldProxySpecification(ObjectSpecificationDescriptor):
+
     def __get__(self, inst, cls=None):
         if inst is None:
             return getObjectSpecification(cls)
@@ -76,8 +82,8 @@ class FieldProxy(object):
 
 
 @implementer(IDataManager)
+@adapter(IFieldProxy, IField)
 class FieldDataManager(AttributeField):
-    adapts(IFieldProxy, IField)
 
     def get(self):
         value = super(FieldDataManager, self).get()
@@ -91,7 +97,7 @@ class FieldDataManager(AttributeField):
         except (AttributeError, ForbiddenAttribute):
             old_value = None
         if isinstance(old_value, Message):
-            value = Message(unicode(old_value),
+            value = Message(six.text_type(old_value),
                             domain=old_value.domain,
                             default=value,
                             mapping=old_value.mapping)
@@ -119,7 +125,7 @@ class FieldEditForm(AutoExtensibleForm, form.EditForm):
 
     @lazy_property
     def additionalSchemata(self):
-        schema_context = self.context.aq_parent
+        schema_context = self.context.__parent__
         return [v for k, v in getAdapters((schema_context, self.field),
                                           interfaces.IFieldEditorExtender)]
 
@@ -161,14 +167,14 @@ class FieldEditForm(AutoExtensibleForm, form.EditForm):
             IStatusMessage(self.request).addStatusMessage(
                 self.noChangesMessage, type='info')
 
-        notify(SchemaModifiedEvent(self.context.aq_parent))
+        notify(SchemaModifiedEvent(self.context.__parent__))
 
     @button.buttonAndHandler(_(u'Cancel'), name='cancel')
     def handleCancel(self, action):
         self.redirectToParent()
 
     def redirectToParent(self):
-        parent = aq_parent(aq_inner(self.context))
+        parent = aq_inner(self.context).__parent__
         url = parent.absolute_url()
         if hasattr(parent, 'schemaEditorView') and parent.schemaEditorView:
             url += '/@@' + parent.schemaEditorView
