@@ -1,6 +1,9 @@
+# -*- coding: utf-8 -*-
+from plone.schemaeditor import _
 from zope import interface
-from zope.schema import interfaces
 from zope import schema
+from zope.schema import interfaces
+
 
 try:
     from plone.app.z3cform.widget import IDatetimeField as IDatetime
@@ -17,8 +20,6 @@ except ImportError:
         IDatetime = interfaces.IDatetime
         IDate = interfaces.IDate
 
-from plone.schemaeditor import _
-
 
 # get rid of unhelpful help text
 interfaces.IMinMaxLen['min_length'].description = u''
@@ -101,5 +102,5 @@ class ITextLineChoice(interfaces.IField):
         description=interfaces.IChoice['vocabularyName'].description,
         default=interfaces.IChoice['vocabularyName'].default,
         required=False,
-        vocabulary="plone.schemaeditor.VocabulariesVocabulary",
+        vocabulary='plone.schemaeditor.VocabulariesVocabulary',
     )
